Tax-Calculator
==============

## What is Tax-Calculator?

Tax-Calculator is an open-source microsimulation model for static analysis of
USA federal income and payroll taxes.
You can install it with [Anaconda](https://www.anaconda.com/products/individual)
via:

```
conda update taxcalc
```

or with [PyPI](https://pypi.org/project/taxcalc/) via:

```
pip install taxcalc
```

When using
[micro data](https://github.com/PSLmodels/taxdata#about-taxdata-repository)
that represent the USA population, Tax-Calculator can estimate the aggregate
revenue and distributional effects of tax reforms under static analysis
assumptions.

Tax-Calculator can also process custom-created data on one or more filing
units permitting analysis of how tax reforms affect certain people.

Tax-Calculator interacts with other models in the
[Policy Simulation Library](https://www.pslmodels.org/) to conduct non-static
analysis.

Tax-Calculator is transparent because its Python source code and embedded
documentation are publicly available at the
[Tax-Calculator GitHub repository](https://github.com/PSLmodels/Tax-Calculator).

Tax-Calculator can simulate an enormous number of tax reforms because tax policy
is parameterized using over 200 parameters that can be changed by users
**without doing any programming**.
And even a reform that is not able to be characterized using
currently-available parameters can be simulated by writing supplementary Python
code that characterizes the reform.

Tax-Calculator can estimate for each filing unit the marginal tax rate
generated by a small change in income.
Marginal tax rates can be generated for eighteen different kinds of income.
And marginal tax rates can be estimated under any parametric tax reform.

Tax-Calculator is extensively tested using hundreds of unit and integration
tests that achieve complete code coverage.
Also, there is an ongoing cross-model validation effort that uses large
randomly-generated samples of filing units to compare results generated by
Tax-Calculator with results from other tax models.
The cross-model validation work with NBER's TAXSIM-27 model is described
[here](https://github.com/PSLmodels/Tax-Calculator/blob/master/taxcalc/validation/taxsim27/README.md#validation-of-tax-calculator-against-internet-taxsim-27).

## Latest release

{doc}`4.2.2 (2024-09-14) <about/releases>`

If you are already using Tax-Calculator, upgrade using the following command:

```
conda update conda-forge::taxcalc
```

or

```
pip install -U taxcalc
```

If you're a new user, read {doc}`usage/starting`.

## Disclaimer

Results will change as Tax-Calculator data and logic improve.
A fundamental reason for adopting open-source methods in this project is so
that people from all backgrounds can contribute to the models that our society
uses to assess economic policy; when community-contributed improvements are
incorporated, the model will produce different results.

## Citing Tax-Calculator

Please cite the source of your analysis as
"Tax-Calculator release #.#.#, author's calculations".
If you wish to provide a link to Tax-Calculator, the preferred URL is:
`https://PSLmodels.github.io/Tax-Calculator`.
Additionally, we strongly recommend that you describe the input data used,
and provide a link to the materials required to replicate your analysis or,
at least, note that those materials are available upon request.